#!/bin/sh
# BEGIN COPYRIGHT
# **************************************************************************
# 
#  Licensed Materials - Property of IBM
#  5725-C94, 5725-C95, 5725-C96
#  (C) Copyright IBM Corporation 2010, 2012. All Rights Reserved.
#  US Government Users Restricted Rights- Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
# 
# **************************************************************************

usage() {
    echo -e -n "\n"
    echo "Usage: perfDWTool.sh [options...] <command>"
    echo -e -n "\n"
    echo "Options:"
    echo "    -?, -help                             print this message"
    echo "    -u <username>, -username <username>   user name of the performance DW user"
    echo "    -p <password>, -password <password>   user password (unencrypted)"
    echo "    -nodeName <name>                      node name in an ND Environment"
    echo "    -serverName <name>                    server name in an ND Environment"
    echo -e -n "\n"
    echo "Commands:"
    echo " pending [schema-command-args] [-groups tracking-group-name-1 tracking-group-name-2 ...]"
    echo " archive [snapshot-id-1 snapshot-id-2 ...]"
    echo " restore [snapshot-id-1 snapshot-id-2 ...]"
    echo " prune [prune-command-args]"
    echo -e -n "\n"
    echo "Prune Command Args:"
    echo " -daysOld number-of-days-old"
    echo -e -n "\n"
    echo "Schema Command Args:"
    echo " -preview output-file-name"
    echo " -prepare output-file-name"
    echo " -execute"
    echo -e -n "\n"
    exit $1
}

CURR_PROFILE_BIN_DIR=`pwd`
. $CURR_PROFILE_BIN_DIR/setupCmdLine.sh

PERF_DW_TOOL_HOME=$WAS_HOME/BPM/Lombardi/tools/perfdw-tool
BPM_LIB=$WAS_HOME/BPM/Lombardi/lib
PDW_LIB=$WAS_HOME/BPM/Lombardi/performance-data-warehouse/lib
PS_INIT_LIB=$WAS_HOME/BPM/Lombardi/process-server/twinit/lib

STARTING_ARGS=$*

USERNAME=
PASSWORD=
PDW_NODE_NAME=
PDW_SERVER_NAME=
JDBC_DRIVER_PATH=/shared/db2a10/jdbc/classes/db2jcc.jar

FINISHED='0'
until [ "$#" = "0" -o $FINISHED = '1' ]
do
    case "$1" in
        '-help'|'-?')
            usage 0
            ;;
        '-USER_INSTALL_ROOT')
            USER_INSTALL_ROOT=$2
            shift;shift
            ;;
        '-u')
            USERNAME=$2
            shift;shift
            ;;
        '-p')
            PASSWORD=$2
            shift;shift
            ;;
        '-username')
            USERNAME=$2
            shift;shift
            ;;
        '-password')
            PASSWORD=$2
            shift;shift
            ;;
        '-nodeName')
            PDW_NODE_NAME=$2
            shift;shift
            ;;
        '-serverName')
            PDW_SERVER_NAME=$2
            shift;shift
            ;;
        *)
            FINISHED='1'
            ;;
    esac
done

COMMAND_ARGS="-username $USERNAME -password $PASSWORD $*"

PDW_NODE_NAME_EXISTS=""
PDW_NODE_NAME_EXISTS=`find $USER_INSTALL_ROOT/config/cells -name $PDW_NODE_NAME`

if [ $PDW_NODE_NAME_EXISTS ]
then
  # echo "CONTINUE: nodeName $PDW_NODE_NAME exists."
  # need the colon below to serve as a no-op, or else the comment above will produce a syntax error
  :
else
  echo "EXIT: nodeName $PDW_NODE_NAME does not exist."
  exit $?
fi

PERF_SERVER_CONFIG=""
PERF_SERVER_CONFIG=`find $USER_INSTALL_ROOT/config/cells -name "performance-data-warehouse" |grep $PDW_NODE_NAME/servers`

if [ $PERF_SERVER_CONFIG ]
then
  # echo "CONTINUE: Directory $PERF_SERVER_CONFIG exists."
  # need the colon below to serve as a no-op, or else the comment above will produce a syntax error
  :
else 
  echo "EXIT: Cannot locate directory $USER_INSTALL_ROOT/config/cells/**/performance-data-warehouse"
  exit $?
fi

MAX_MEM=-Xmx320m
U_INSTALL_ROOT="-Duser.install.root=$USER_INSTALL_ROOT"
TW_SERVER_HOME="-Dteamworks.server.home=$PERF_SERVER_CONFIG"
  # echo "TW_SERVER_HOME = $TW_SERVER_HOME"
TW_CONFIG_ROOT_HOME="-Dconfig.root=$PERF_SERVER_CONFIG"
  # echo "TW_CONFIG_ROOT_HOME = $TW_CONFIG_ROOT_HOME"
TW_PLATFORM="-Dteamworks.applicationServerPlatform=WebSphere 8.0"
TW_ENV_NAME="-Dcom.lombardisoftware.core.TWEnvironment.environmentName=ENVIRONMENT_PERFORMANCE_SERVER"
PDW_TRUE="-DPERFORMANCEDW=true"
LOGGING_ARG="-Djava.util.logging.config.file=$PERF_DW_TOOL_HOME/resources/logging.properties -Dtw.log4j.init=false"

CLASSPATH=$PERF_DW_TOOL_HOME
CLASSPATH=$CLASSPATH:$PERF_DW_TOOL_HOME/resources
CLASSPATH=$CLASSPATH:$BPM_LIB/twant.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/twperfsvrtool.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/svrcoreclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/spring.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/psclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/utility.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/langutil.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/harmony-concurrent-locks.jar
CLASSPATH=$CLASSPATH:$PDW_LIB/twperfsvrclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/castor.jar
CLASSPATH=$CLASSPATH:$BPM_LIB/jdom.jar
CLASSPATH=$CLASSPATH:$PS_INIT_LIB/dbstructure.jar

CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.bpm.config.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ffdc.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/javax.j2ee.ejb.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.emf.jar

CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.prereq.jaxrs.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.prereq.commons-logging.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.hpel.logging.jar

CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.core.runtime_.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.common_.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.registry.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.emf.ecore.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.emf.common.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.osgi_.jar

THIN_CLIENT_JAR=""
THIN_CLIENT_JAR=`find $WAS_HOME/runtimes -name "com.ibm.ws.ejb.thinclient_*.jar"`

if [ $THIN_CLIENT_JAR ]
then
  # echo "CONTINUE: Jar file com.ibm.ws.ejb.thinclient_*.jar exists at $THIN_CLIENT_JAR"
  # need the colon below to serve as a no-op, or else the comment above will produce a syntax error
  :
else
  echo "EXIT: Jar file com.ibm.ws.ejb.thinclient_*.jar does not exist under the $WAS_HOME/runtimes directory."
  exit $?
fi
CLASSPATH=$CLASSPATH:$THIN_CLIENT_JAR

CLASSPATH=$CLASSPATH:$WAS_HOME/lib/bootstrap.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.runtime.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.proxy.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.admin.core.jar

CLASSPATH=$CLASSPATH:$JDBC_DRIVER_PATH

TWPERF_SERVER_JAR=""
TWPERF_SERVER_JAR=`find $USER_INSTALL_ROOT/installedApps -name "twperfsvr-ejb.jar"`

if [ $TWPERF_SERVER_JAR ]
then
  # echo "CONTINUE: Jar file twperfsvr-ejb.jar exists at $TWPERF_SERVER_JAR"
  # need the colon below to serve as a no-op, or else the comment above will produce a syntax error
  :
else
  echo "EXIT: Jar file twperfsvr-ejb.jar does not exist under the $USER_INSTALL_ROOT/installedApps directory."
  exit $?
fi

CLASSPATH=$CLASSPATH:$TWPERF_SERVER_JAR

export LIBPATH=$WAS_HOME/lib:$LIBPATH

#echo $JAVA_HOME/bin/java $MAX_MEM $TW_SERVER_HOME $TW_CONFIG_ROOT_HOME "$TW_PLATFORM" $TW_ENV_NAME $PDW_TRUE $LOGGING_ARG $U_INSTALL_ROOT -Dwas.install.root=${WAS_HOME} "$CLIENTSAS" $JAASSOAP "$CLIENTSSL" -Dserver.root="$WAS_HOME" -Dws.ext.dirs=${WAS_EXT_DIRS}:${WAS_USER_DIRS} -Djava.endorsed.dirs=$WAS_ENDORSED_DIRS $USER_INSTALL_PROP -classpath $WAS_CLASSPATH:$CLASSPATH com.ibm.ws.bootstrap.WSLauncher com.lombardisoftware.tools.tracking.ant.ToolLauncher $COMMAND_ARGS

$JAVA_HOME/bin/java $MAX_MEM $TW_SERVER_HOME $TW_CONFIG_ROOT_HOME "$TW_PLATFORM" $TW_ENV_NAME $PDW_TRUE $LOGGING_ARG $U_INSTALL_ROOT -Dwas.install.root=${WAS_HOME} "$CLIENTSAS" $JAASSOAP "$CLIENTSSL" -Dserver.root="$WAS_HOME" -Dws.ext.dirs=${WAS_EXT_DIRS}:${WAS_USER_DIRS} -Djava.endorsed.dirs=$WAS_ENDORSED_DIRS $USER_INSTALL_PROP -classpath $WAS_CLASSPATH:$CLASSPATH com.ibm.ws.bootstrap.WSLauncher com.lombardisoftware.tools.tracking.ant.ToolLauncher $COMMAND_ARGS

if [ "$?" -ne "0" ]
then
    # echo "Failed, please see logs for further details."
    # echo -e -n "\n"
    exit $?
fi
